gradm2 behöver en enhet:
gradm2 behöver en specialenhet, en enhet kallad /dev/grsec2 för
att kommunicera med kärnan. Den kommer att skapas åt dig, om du
inte redan har den, och du inte har devfs eller udev.
