Změny politiky/nové možnosti:
S verzí 2.1.6 se v gradm2 pozměnil soubor s politikou a také
jeho možnosti. Dále existuje nová binárka nazvaná gradm_pam.
Podrobnosti naleznete v souboru README a v ukázkovém souboru s
politikou.
